@@ -4,10 +4,10 @@ from typing import List
 import numpy as np
 from lazy import lazy
 
-from evobench.separable import Separable
+from evobench.continuous.continuous import Continuous
 
 
-class Multimodal(Separable):
+class Multimodal(Continuous):
 
     def __init__(
         self,
