@@ -70,6 +70,25 @@ class IsingSpinGlass(Benchmark):
 
         return as_dict
 
+    @lazy
+    def lower_bound(self) -> np.ndarray:
+        lower_bound = [0.0] * self.genome_size
+        return np.array(lower_bound)
+
+    @lazy
+    def upper_bound(self) -> np.ndarray:
+        upper_bound = [1.0] * self.genome_size
+        return np.array(upper_bound)
+
+    def random_solution(self) -> Solution:
+        genome = np.random.uniform(low=0, high=2, size=self.genome_size)
+
+        genome *= self.bound_range
+        genome -= self.lower_bound
+        genome = genome.astype(dtype=np.int)
+
+        return Solution(genome)
+
     def _evaluate_solution(self, solution: Solution) -> float:
 
         energy = 0.0
