@@ -2,7 +2,6 @@ from dataclasses import dataclass
 from typing import List
 
 import numpy as np
-from lazy import lazy
 
 from .solution import Solution
 
@@ -15,7 +14,15 @@ class Population:
     def length(self) -> int:
         return len(self.solutions)
 
-    @lazy
+    @property
+    def upper_bound(self) -> np.ndarray:
+        return self.as_ndarray.max(axis=0)
+
+    @property
+    def lower_bound(self) -> np.ndarray:
+        return self.as_ndarray.min(axis=0)
+
+    @property
     def as_ndarray(self) -> np.ndarray:
         population = [solution.genome for solution in self.solutions]
         population = np.array(population)
