@@ -1,22 +1,14 @@
 import numpy as np
 from pytest import fixture
 
-from evobench.discrete.initialization import Uniform
 from evobench.discrete.trap import Trap
 from evobench.model import Population
 
 from ..benchmark import Benchmark
-from ..initialization import Initialization
-
 
 __POPULATION_SIZE = 20
 
 
-@fixture(scope='session')
-def initialization() -> Initialization:
-    return Uniform(__POPULATION_SIZE)
-
-
 @fixture(
     scope='module',
     params=[(False, True), (True, False)],
@@ -33,12 +25,8 @@ def benchmark(request) -> Benchmark:
 
 
 @fixture(scope='module')
-def population(
-    initialization: Initialization,
-    benchmark: Benchmark
-) -> Population:
-
-    return initialization.initialize_population(benchmark.genome_size)
+def population(benchmark: Benchmark) -> Population:
+    return benchmark.initialize_population(__POPULATION_SIZE)
 
 
 def test_evaluate_population(benchmark: Benchmark, population: Population):
